/*
** Module   : Event.java
** Abstract : Definition of Widget Browser UI events.
**
** Copyright (c) 2014, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- ---------------------------------Description----------------------------------
** 001 HC  20141031 Created initial version
*/
package com.goldencode.p2j.ui.client.widgetbrowser;

import java.awt.event.ActionEvent;

import com.goldencode.p2j.ui.client.widget.Widget;

/**
 * The class defines the available Widget Browser UI events
 * and their structure.
 */
@SuppressWarnings("serial")
public class Event 
extends ActionEvent
{
   /**
    * The event is triggered when widget selection changes.
    */
   public static final int WIDGET_SELECTION_CHANGED = 1;
   
   /**
    * Triggered when Widget Browser main window is closed.
    */
   public static final int BROWSER_CLOSED = 2;
   
   /**
    * Triggered when property value is selected.
    */
   public static final int PROPERTY_VALUE_NAVIGATED = 3;
   
   /**
    * The event-related widget instance.
    */
   public Widget<?> widget;
   
   /**
    * The event-related property value.
    */
   public Object propertyValue;

   
   /**
    * Event constructor.
    *  
    * @param   source
    *          A reference to the source o fthe event.
    * @param   id
    *          Event id.
    * @param   widget
    *          A reference to the event-related widget, may be null.
    */
   public Event(Object source, int id, Widget<?> widget)
   {
      super(source, id, null);
      this.widget = widget;
   }
   
   /**
    * Event constructor.
    *  
    * @param   source
    *          A reference to the source o fthe event.
    * @param   id
    *          Event id.
    * @param   propertyValue
    *          A reference to the event-related property value.
    */
   public Event(Object source, int id, Object propertyValue)
   {
      super(source, id, null);
      this.propertyValue = propertyValue;
   }
}
